/*                                                                    */
/* wmab-0.1                                                           */
/*                                                                    */
/* A  WindowMaker dockable  application that  allows laptop  users to */
/* graphically  monitor  the  status  of their  power  source.  (I.e. */
/* whether or not AC or battery is in use as well as how long it will */
/* take  to  drain  or  charge the  battery.)  It  supports  multiple */
/* batteries simple with -b option.                                   */
/*                                                                    */
/* Written by Filippo Panessa  <kalem@linux.it> and copyrighted under */
/* GPL.                                                               */
/*                                                                    */
/* This  file  is  based  on wmacpi's idea  originally  written  (and */
/* copyrighted under GPL) by Timecop <timecop@japan.co.jp>.           */
/*                                                                    */
/*                                                                    */
/* This  program is  free software;  you can  redistribute it  and/or */
/* modify it  under the terms  of the  GNU General Public  License as */
/* published by  the Free Software  Foundation; either version  2, or */
/* (at your option) any later version.                                */
/*                                                                    */
/* This program  is distributed in the  hope that it will  be useful, */
/* but WITHOUT  ANY WARRANTY;  without even  the implied  warranty of */
/* MERCHANTABILITY or FITNESS  FOR A PARTICULAR PURPOSE.  See the GNU */
/* General Public License for more details.                           */
/*                                                                    */
/* You should have received a copy  of the GNU General Public License */
/* along with this  program (see the file COPYING); if  not, write to */
/* the Free Software  Foundation, Inc., 59 Temple Place  - Suite 330, */
/* Boston, MA 02111-1307, USA                                         */
/*                                                                    */
/*                                                                    */
/*                                                                    */

#define MAXBATT 8

typedef enum
{
  POWER,			/* on AC, Battery charged  */
  DISCHARGING,			/* on Battery, Discharging */
  CHARGING,			/* on AC, Charging         */
  UNKNOW			/* unknow                  */
}
Charging;

typedef struct
{
  int present;			/* 1 if present, 0 if no battery         */
  int capacity;			/* 1 ok, 0 critical                      */
  Charging state;		/* charging state enum                   */
  int prate;			/* present rate                          */
  int rcapacity;		/* rameining capacity                    */
  int pvoltage;			/* present voltage                       */

  /* not present in /proc */
  int rtime;			/* remaining time                        */
  int percentage;		/* battery percentage (-1 if no battery) */
}
ACPIstate;

typedef struct
{
  int present;			/* 1 if present, 0 if no battery        */
  int design_capacity;		/* design capacity                      */
  int last_full_capacity;	/* last_full_capacity                   */
  int battery_technology;	/* 1 non-rechargeable, 0 rechargeable   */
  int design_voltage;		/* design voltage                       */
  int design_capacity_warning;	/* design capacity warning (critical)   */
  int design_capacity_low;	/* design capacity low (low level)      */
  int capacity_granularity_1;	/* capacity granularity info (1)        */
  int capacity_granularity_2;	/* capacity granularity info (2)        */
  char model_number;		/* model number info                    */
  char serial_number;		/* unique serial number                 */
  char battery_type;		/* battery type (materials)             */
  char OEM_info;		/* OEM battery info                     */
}
ACPIinfo;

typedef struct
{
  int state;			/* 1 if online, 0 if offline            */
}
ACADstate;

/* global */
ACPIstate *acpistate;
ACPIinfo *acpiinfo;
ACADstate *acadstate;

static char batteries[MAXBATT][128];
static char battinfo[MAXBATT][128];

/* batteries detected */
int batt_count;

/* temp buffer */
char buf[512];

int check_acpi ();
int read_acad_state ();
int read_acpi_info (int battery);
int read_acpi_state (int battery);
